@@ -1,7 +1,7 @@
 /*
     SPDX-License-Identifier: GPL-2.0-or-later
     SPDX-FileCopyrightText: 2009 Alexander Rieder <alexanderrieder@gmail.com>
-    SPDX-FileCopyrightText: 2019 Alexander Semke <alexander.semke@web.de>
+    SPDX-FileCopyrightText: 2019-2024 Alexander Semke <alexander.semke@web.de>
 */
 
 #include "session.h"
@@ -40,22 +40,12 @@ class Cantor::SessionPrivate
 Session::Session(Backend* backend ) : QObject(backend), d(new SessionPrivate)
 {
     d->backend = backend;
-
-#ifdef WITH_EPS
-    if (Cantor::LatexRenderer::isLatexAvailable())
-        d->typesettingEnabled = Settings::self()->typesetDefault();
-#endif
 }
 
 Session::Session(Backend* backend, DefaultVariableModel* model) : QObject(backend), d(new SessionPrivate)
 {
     d->backend = backend;
     d->variableModel = model;
-
-#ifdef WITH_EPS
-    if (Cantor::LatexRenderer::isLatexAvailable())
-        d->typesettingEnabled = Settings::self()->typesetDefault();
-#endif
 }
 
 Session::~Session()
@@ -63,53 +53,6 @@ Session::~Session()
     delete d;
 }
 
-void Cantor::Session::testGraphicsPackages(QList<GraphicPackage> packages)
-{
-    std::map<QString, bool> handlingStatus;
-
-    QEventLoop loop;
-    for (GraphicPackage& package : packages)
-    {
-        if (GraphicPackage::findById(package, d->usableGraphicPackages) != -1)
-            continue;
-
-        handlingStatus[package.id()] = false;
-        Expression* expr = package.isAvailable(this);
-
-        connect(expr, &Expression::expressionFinished, [this, expr, &package, &loop, &handlingStatus](Expression::Status status) {
-            if (status == Expression::Status::Done) {
-                if (expr->result() != nullptr
-                    && expr->result()->type() == TextResult::Type
-                    && expr->result()->data().toString() == QLatin1String("1")) {
-                    this->d->usableGraphicPackages.push_back(package);
-                }
-            } else {
-                qDebug() << "test presence command for" << package.id() << "finished because of" << (status == Expression::Error ? "error" : "interrupt");
-                if (status == Expression::Error && expr)
-                    qDebug() << "error message:" << expr->errorMessage();
-            }
-
-            handlingStatus[package.id()] = true;
-
-            bool allExpersionsFinished = true;
-            for (auto& iter : handlingStatus)
-            {
-                if (iter.second == false)
-                {
-                    allExpersionsFinished = false;
-                    break;
-                }
-            }
-
-            if (allExpersionsFinished)
-                loop.exit();
-        });
-    }
-    // If handlingStatus size is empty (it means, that no connections have been done), then we will stay in the 'loop' event loop forever
-    if (handlingStatus.size() != 0)
-        loop.exec();
-}
-
 void Session::logout()
 {
     if (d->status == Session::Running)
@@ -388,3 +331,50 @@ void Cantor::Session::updateEnabledGraphicPackages(const QList<Cantor::GraphicPa
         }
     }
 }
+
+void Cantor::Session::testGraphicsPackages(QList<GraphicPackage> packages)
+{
+    std::map<QString, bool> handlingStatus;
+
+    QEventLoop loop;
+    for (GraphicPackage& package : packages)
+    {
+        if (GraphicPackage::findById(package, d->usableGraphicPackages) != -1)
+            continue;
+
+        handlingStatus[package.id()] = false;
+        Expression* expr = package.isAvailable(this);
+
+        connect(expr, &Expression::expressionFinished, [this, expr, &package, &loop, &handlingStatus](Expression::Status status) {
+            if (status == Expression::Status::Done) {
+                if (expr->result() != nullptr
+                    && expr->result()->type() == TextResult::Type
+                    && expr->result()->data().toString() == QLatin1String("1")) {
+                    this->d->usableGraphicPackages.push_back(package);
+                }
+            } else {
+                qDebug() << "test presence command for" << package.id() << "finished because of" << (status == Expression::Error ? "error" : "interrupt");
+                if (status == Expression::Error && expr)
+                    qDebug() << "error message:" << expr->errorMessage();
+            }
+
+            handlingStatus[package.id()] = true;
+
+            bool allExpersionsFinished = true;
+            for (auto& iter : handlingStatus)
+            {
+                if (iter.second == false)
+                {
+                    allExpersionsFinished = false;
+                    break;
+                }
+            }
+
+            if (allExpersionsFinished)
+                loop.exit();
+        });
+    }
+    // If handlingStatus size is empty (it means, that no connections have been done), then we will stay in the 'loop' event loop forever
+    if (handlingStatus.size() != 0)
+        loop.exec();
+}
